@@ -198,6 +198,16 @@ public class BuildAndDecodeTest extends BaseTest {
         compareXmlFiles("res/xml/references.xml");
     }
 
+    @Test
+    public void xmlXsdFileTest() throws BrutException {
+        compareXmlFiles("res/xml/ww_box_styles_schema.xsd");
+    }
+
+    @Test
+    public void xmlIdsEmptyTest() throws BrutException {
+        compareXmlFiles("res/values/ids.xml");
+    }
+
     @Test
     public void xmlReferenceAttributeTest() throws BrutException {
         compareXmlFiles("res/layout/issue1040.xml");
@@ -231,7 +241,7 @@ public class BuildAndDecodeTest extends BaseTest {
     @Test
     public void qualifiersTest() throws BrutException {
         compareValuesFiles("values-mcc004-mnc4-en-rUS-ldrtl-sw100dp-w200dp-h300dp"
-                + "-xlarge-long-round-highdr-land-desk-night-xhdpi-finger-keyssoft-12key"
+                + "-long-round-highdr-land-desk-night-xhdpi-finger-keyssoft-12key"
                 + "-navhidden-dpad-v26/strings.xml");
     }
 
